@@ -3,11 +3,10 @@ import warnings
 warnings.simplefilter("ignore")
 
 from akerbp.mlops.training.service import service
-from akerbp.mlops.core import logger
+from akerbp.mlops.utils import logger
 
 logging=logger.get_logger()
 
-
 def handle(data, secrets):
    try:
       return service(data, secrets)
